@@ -1,21 +1,12 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/networkmanager/NetworkManager_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/networkmanager/model/AWSLocation.h>
 #include <aws/networkmanager/model/Location.h>
 #include <aws/core/utils/DateTime.h>
 #include <aws/networkmanager/model/DeviceState.h>
@@ -175,6 +166,37 @@ namespace Model
     inline Device& WithGlobalNetworkId(const char* value) { SetGlobalNetworkId(value); return *this;}
 
 
+    /**
+     * <p>The AWS location of the device.</p>
+     */
+    inline const AWSLocation& GetAWSLocation() const{ return m_aWSLocation; }
+
+    /**
+     * <p>The AWS location of the device.</p>
+     */
+    inline bool AWSLocationHasBeenSet() const { return m_aWSLocationHasBeenSet; }
+
+    /**
+     * <p>The AWS location of the device.</p>
+     */
+    inline void SetAWSLocation(const AWSLocation& value) { m_aWSLocationHasBeenSet = true; m_aWSLocation = value; }
+
+    /**
+     * <p>The AWS location of the device.</p>
+     */
+    inline void SetAWSLocation(AWSLocation&& value) { m_aWSLocationHasBeenSet = true; m_aWSLocation = std::move(value); }
+
+    /**
+     * <p>The AWS location of the device.</p>
+     */
+    inline Device& WithAWSLocation(const AWSLocation& value) { SetAWSLocation(value); return *this;}
+
+    /**
+     * <p>The AWS location of the device.</p>
+     */
+    inline Device& WithAWSLocation(AWSLocation&& value) { SetAWSLocation(std::move(value)); return *this;}
+
+
     /**
      * <p>The description of the device.</p>
      */
@@ -565,6 +587,9 @@ namespace Model
     Aws::String m_globalNetworkId;
     bool m_globalNetworkIdHasBeenSet;
 
+    AWSLocation m_aWSLocation;
+    bool m_aWSLocationHasBeenSet;
+
     Aws::String m_description;
     bool m_descriptionHasBeenSet;
 
