@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/rds/RDS_EXPORTS.h>
@@ -38,11 +28,9 @@ namespace Model
 {
 
   /**
-   * <note> <p>This is prerelease documentation for the RDS Database Proxy feature in
-   * preview release. It is subject to change.</p> </note> <p>The data structure
-   * representing a proxy managed by the RDS Proxy.</p> <p>This data type is used as
-   * a response element in the <code>DescribeDBProxies</code> action.</p><p><h3>See
-   * Also:</h3>   <a
+   * <p>The data structure representing a proxy managed by the RDS Proxy.</p> <p>This
+   * data type is used as a response element in the <code>DescribeDBProxies</code>
+   * action.</p><p><h3>See Also:</h3>   <a
    * href="http://docs.aws.amazon.com/goto/WebAPI/rds-2014-10-31/DBProxy">AWS API
    * Reference</a></p>
    */
@@ -191,54 +179,95 @@ namespace Model
 
 
     /**
-     * <p>Currently, this value is always <code>MYSQL</code>. The engine family applies
-     * to both RDS MySQL and Aurora MySQL.</p>
+     * <p>The engine family applies to MySQL and PostgreSQL for both RDS and
+     * Aurora.</p>
      */
     inline const Aws::String& GetEngineFamily() const{ return m_engineFamily; }
 
     /**
-     * <p>Currently, this value is always <code>MYSQL</code>. The engine family applies
-     * to both RDS MySQL and Aurora MySQL.</p>
+     * <p>The engine family applies to MySQL and PostgreSQL for both RDS and
+     * Aurora.</p>
      */
     inline bool EngineFamilyHasBeenSet() const { return m_engineFamilyHasBeenSet; }
 
     /**
-     * <p>Currently, this value is always <code>MYSQL</code>. The engine family applies
-     * to both RDS MySQL and Aurora MySQL.</p>
+     * <p>The engine family applies to MySQL and PostgreSQL for both RDS and
+     * Aurora.</p>
      */
     inline void SetEngineFamily(const Aws::String& value) { m_engineFamilyHasBeenSet = true; m_engineFamily = value; }
 
     /**
-     * <p>Currently, this value is always <code>MYSQL</code>. The engine family applies
-     * to both RDS MySQL and Aurora MySQL.</p>
+     * <p>The engine family applies to MySQL and PostgreSQL for both RDS and
+     * Aurora.</p>
      */
     inline void SetEngineFamily(Aws::String&& value) { m_engineFamilyHasBeenSet = true; m_engineFamily = std::move(value); }
 
     /**
-     * <p>Currently, this value is always <code>MYSQL</code>. The engine family applies
-     * to both RDS MySQL and Aurora MySQL.</p>
+     * <p>The engine family applies to MySQL and PostgreSQL for both RDS and
+     * Aurora.</p>
      */
     inline void SetEngineFamily(const char* value) { m_engineFamilyHasBeenSet = true; m_engineFamily.assign(value); }
 
     /**
-     * <p>Currently, this value is always <code>MYSQL</code>. The engine family applies
-     * to both RDS MySQL and Aurora MySQL.</p>
+     * <p>The engine family applies to MySQL and PostgreSQL for both RDS and
+     * Aurora.</p>
      */
     inline DBProxy& WithEngineFamily(const Aws::String& value) { SetEngineFamily(value); return *this;}
 
     /**
-     * <p>Currently, this value is always <code>MYSQL</code>. The engine family applies
-     * to both RDS MySQL and Aurora MySQL.</p>
+     * <p>The engine family applies to MySQL and PostgreSQL for both RDS and
+     * Aurora.</p>
      */
     inline DBProxy& WithEngineFamily(Aws::String&& value) { SetEngineFamily(std::move(value)); return *this;}
 
     /**
-     * <p>Currently, this value is always <code>MYSQL</code>. The engine family applies
-     * to both RDS MySQL and Aurora MySQL.</p>
+     * <p>The engine family applies to MySQL and PostgreSQL for both RDS and
+     * Aurora.</p>
      */
     inline DBProxy& WithEngineFamily(const char* value) { SetEngineFamily(value); return *this;}
 
 
+    /**
+     * <p>Provides the VPC ID of the DB proxy.</p>
+     */
+    inline const Aws::String& GetVpcId() const{ return m_vpcId; }
+
+    /**
+     * <p>Provides the VPC ID of the DB proxy.</p>
+     */
+    inline bool VpcIdHasBeenSet() const { return m_vpcIdHasBeenSet; }
+
+    /**
+     * <p>Provides the VPC ID of the DB proxy.</p>
+     */
+    inline void SetVpcId(const Aws::String& value) { m_vpcIdHasBeenSet = true; m_vpcId = value; }
+
+    /**
+     * <p>Provides the VPC ID of the DB proxy.</p>
+     */
+    inline void SetVpcId(Aws::String&& value) { m_vpcIdHasBeenSet = true; m_vpcId = std::move(value); }
+
+    /**
+     * <p>Provides the VPC ID of the DB proxy.</p>
+     */
+    inline void SetVpcId(const char* value) { m_vpcIdHasBeenSet = true; m_vpcId.assign(value); }
+
+    /**
+     * <p>Provides the VPC ID of the DB proxy.</p>
+     */
+    inline DBProxy& WithVpcId(const Aws::String& value) { SetVpcId(value); return *this;}
+
+    /**
+     * <p>Provides the VPC ID of the DB proxy.</p>
+     */
+    inline DBProxy& WithVpcId(Aws::String&& value) { SetVpcId(std::move(value)); return *this;}
+
+    /**
+     * <p>Provides the VPC ID of the DB proxy.</p>
+     */
+    inline DBProxy& WithVpcId(const char* value) { SetVpcId(value); return *this;}
+
+
     /**
      * <p>Provides a list of VPC security groups that the proxy belongs to.</p>
      */
@@ -430,49 +459,49 @@ namespace Model
 
 
     /**
-     * <p>The endpoint that you can use to connect to the proxy. You include the
+     * <p>The endpoint that you can use to connect to the DB proxy. You include the
      * endpoint value in the connection string for a database client application.</p>
      */
     inline const Aws::String& GetEndpoint() const{ return m_endpoint; }
 
     /**
-     * <p>The endpoint that you can use to connect to the proxy. You include the
+     * <p>The endpoint that you can use to connect to the DB proxy. You include the
      * endpoint value in the connection string for a database client application.</p>
      */
     inline bool EndpointHasBeenSet() const { return m_endpointHasBeenSet; }
 
     /**
-     * <p>The endpoint that you can use to connect to the proxy. You include the
+     * <p>The endpoint that you can use to connect to the DB proxy. You include the
      * endpoint value in the connection string for a database client application.</p>
      */
     inline void SetEndpoint(const Aws::String& value) { m_endpointHasBeenSet = true; m_endpoint = value; }
 
     /**
-     * <p>The endpoint that you can use to connect to the proxy. You include the
+     * <p>The endpoint that you can use to connect to the DB proxy. You include the
      * endpoint value in the connection string for a database client application.</p>
      */
     inline void SetEndpoint(Aws::String&& value) { m_endpointHasBeenSet = true; m_endpoint = std::move(value); }
 
     /**
-     * <p>The endpoint that you can use to connect to the proxy. You include the
+     * <p>The endpoint that you can use to connect to the DB proxy. You include the
      * endpoint value in the connection string for a database client application.</p>
      */
     inline void SetEndpoint(const char* value) { m_endpointHasBeenSet = true; m_endpoint.assign(value); }
 
     /**
-     * <p>The endpoint that you can use to connect to the proxy. You include the
+     * <p>The endpoint that you can use to connect to the DB proxy. You include the
      * endpoint value in the connection string for a database client application.</p>
      */
     inline DBProxy& WithEndpoint(const Aws::String& value) { SetEndpoint(value); return *this;}
 
     /**
-     * <p>The endpoint that you can use to connect to the proxy. You include the
+     * <p>The endpoint that you can use to connect to the DB proxy. You include the
      * endpoint value in the connection string for a database client application.</p>
      */
     inline DBProxy& WithEndpoint(Aws::String&& value) { SetEndpoint(std::move(value)); return *this;}
 
     /**
-     * <p>The endpoint that you can use to connect to the proxy. You include the
+     * <p>The endpoint that you can use to connect to the DB proxy. You include the
      * endpoint value in the connection string for a database client application.</p>
      */
     inline DBProxy& WithEndpoint(const char* value) { SetEndpoint(value); return *this;}
@@ -660,6 +689,9 @@ namespace Model
     Aws::String m_engineFamily;
     bool m_engineFamilyHasBeenSet;
 
+    Aws::String m_vpcId;
+    bool m_vpcIdHasBeenSet;
+
     Aws::Vector<Aws::String> m_vpcSecurityGroupIds;
     bool m_vpcSecurityGroupIdsHasBeenSet;
 
